---
name: "🚀 Feature request"
about: Suggest an idea for improving Scratchip
title: ''
labels: 'type:Enhancement'
assignees: ''

---

### Checklist

- [ ] Did you write out a description of the feature you want to see?
- [ ] Did you look around for any related features?
- [ ] Did you specify relevant external information?

Request a feature? Please fill out the sections below. 👍

### Feature Description

<!--
  Provide a clear and concise description of what the feature is.
-->

### Type of Feature

### Related Features

### Additional context

<!-- choose one -->
**Impact**: no functional change | API addition (no impact on existing code) | API modification | unknown


<!-- choose one -->
**Development Phase**: request | proposal

<!--
  Is there anything else you can add about the proposal?
  You might want to link to related issues here, if you haven't already.
-->
